<p align="center">
  <a title="Project Logo">
    <img height="150" style="margin-top:15px" src="logo/../docs/logo-annotated.svg">
  </a>
</p>

<p align="center">
    <a href="https://github.com/hentai-chan/lolicon/actions?query=workflow%3ACI" title="Continuous Integration">
        <img src="https://github.com/hentai-chan/lolicon/workflows/CI/badge.svg">
    </a>
    <a href="https://github.com/hentai-chan/lolicon/actions?query=workflow%3ACodeQL" title="Code QL Analysis">
        <img src="https://github.com/hentai-chan/lolicon/workflows/CodeQL/badge.svg">
    </a>
    <a href="https://github.com/hentai-chan/lolicon/actions?query=workflow%3APyPI" title="PyPI Build">
        <img src="https://github.com/hentai-chan/lolicon/workflows/PyPI/badge.svg">
    </a>
    <a href="https://pypi.org/project/lolicon/" title="Release Version">
        <img src="https://img.shields.io/pypi/v/lolicon?label=Release">
    </a>
    <a href="https://www.codefactor.io/repository/github/hentai-chan/lolicon" title="Code Factor">
        <img src="https://www.codefactor.io/repository/github/hentai-chan/lolicon/badge?s=73446cb8092f75fb1c893e480473680065734a05">
    </a>
    <a href="https://codecov.io/gh/hentai-chan/lolicon" title="Code Coverage">
        <img src="https://codecov.io/gh/hentai-chan/lolicon/branch/master/graph/badge.svg?token=7KX4DQSZBV">
    </a>
    <a title="Supported Python Versions">
        <img src="https://img.shields.io/badge/Python-%203.8%20%7C%203.9-blue">
    </a>
    <a href="https://www.gnu.org/licenses/gpl-3.0.en.html" title="License Information">
        <img src="https://img.shields.io/badge/License-GPLv3-blue.svg">
    </a>
</p>

## Abstract

This is a STEM project that provides useful utility methods for engineering
sciences and educational purposes. Lolicon bears no relationship to anything but
my fondness of weird project names.

## Note

This is a work in progress. Expect frequent changes to the API. As it stands now,
this library is not ready for production use yet.

## Contact

You can reach me at <dev.hentai-chan@outlook.com> for questions related to this
project.
